@@ -3,7 +3,8 @@ import random
 import sys
 
 from collections import deque
-from ezcode.tree.const import *
+from ezcode.tree.const import DATA_NAME, LEFT_NAME, RIGHT_NAME
+from ezcode.tree.const import LEFT_WING, RIGHT_WING, LEFT_WING_HEAD, RIGHT_WING_HEAD, LEFT_WING_TAIL, RIGHT_WING_TAIL
 
 
 class BinaryTreePrinter:
